@@ -1,4 +1,4 @@
-"""Implements an HTTP API for SoCo-CLI commands."""
+"""Implements an HTTP API server for SoCo-CLI commands."""
 
 from sys import version_info
 
@@ -38,9 +38,11 @@ def command_core(speaker, action, *args, use_local=False):
         exit_code = 1
         result = ""
 
-    # Quote speaker names & arguments with spaces, for neatness
+    # Quote speaker names & arguments containing spaces, for neatness
     if " " in speaker:
-        speaker = '"' + speaker + '"'
+        quoted_speaker = '"' + speaker + '"'
+    else:
+        quoted_speaker = speaker
     new_args = []
     for i in range(len(args)):
         if " " in args[i]:
@@ -48,15 +50,18 @@ def command_core(speaker, action, *args, use_local=False):
         else:
             new_args.append(args[i])
 
-    # Print 'sonos' command and exit code
+    # Print the equivalent 'sonos' command and exit code
     if len(new_args) != 0:
         arguments = (" ".join([arg for arg in new_args])).rstrip()
         print(
-            PREFIX + "Command = 'sonos {} {} {}', ".format(speaker, action, arguments),
+            PREFIX
+            + "Command = 'sonos {} {} {}', ".format(quoted_speaker, action, arguments),
             end="",
         )
     else:
-        print(PREFIX + "Command = 'sonos {} {}', ".format(speaker, action), end="")
+        print(
+            PREFIX + "Command = 'sonos {} {}', ".format(quoted_speaker, action), end=""
+        )
     if exit_code == 0:
         print("exit code = {}".format(exit_code))
     else:
@@ -79,8 +84,10 @@ async def root():
 
 @sc_app.get("/rediscover")
 async def rediscover():
-    rescan_speakers(timeout=5.0)
-    return {"Speakers discovered": get_all_speaker_names()}
+    rescan_speakers(timeout=2.0)
+    speakers = get_all_speaker_names()
+    print(PREFIX + "Speakers (re)discovered: {}".format(speakers))
+    return {"speakers_discovered": speakers}
 
 
 @sc_app.get("/{speaker}/{action}")
@@ -122,13 +129,6 @@ def args_processor():
         default=False,
         help="Print the SoCo-CLI and SoCo versions, and exit",
     )
-    parser.add_argument(
-        "--use-local-speaker-list",
-        "-l",
-        action="store_true",
-        default=False,
-        help="Use the local speaker list instead of SoCo discovery",
-    )
 
     args = parser.parse_args()
 
@@ -140,18 +140,27 @@ def args_processor():
     if args.port is not None:
         PORT = args.port
 
-    global USE_LOCAL
-    if args.use_local_speaker_list is not None:
-        USE_LOCAL = args.use_local_speaker_list
-
 
 def main():
     args_processor()
+    print(PREFIX + "Starting " + INFO)
+
     try:
-        print("Starting " + INFO)
+        # Pre-load speaker cache
+        print(PREFIX + "Finding speakers ... ", end="", flush=True)
+        try:
+            # Try to discover a speaker that doesn't exist, to fully
+            # invoke speaker discovery
+            get_speaker("NULL_54983")
+            print(get_all_speaker_names())
+        except:
+            print("discovery failed, will retry on first request")
+
+        # Start the server
         uvicorn.run(sc_app, host="0.0.0.0", use_colors=False, port=PORT)
         print(INFO + " stopped")
         exit(0)
+
     except Exception as error:
         print("Error: {}".format(error))
         exit(1)
